@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2015-2019 Fanout, Inc.
+ * Copyright (C) 2015-2020 Fanout, Inc.
  *
  * This file is part of Pushpin.
  *
@@ -1854,6 +1854,7 @@ private:
 			{
 				i.type = WsControlPacket::Item::Close;
 				i.code = f.code;
+				i.reason = f.reason;
 			}
 
 			writeWsControlItems(QList<WsControlPacket::Item>() << i);
@@ -2746,31 +2747,15 @@ private slots:
 				if(params.isEmpty() || params[0].first.isEmpty())
 					continue;
 
-				QList<QByteArray> type = params[0].first.split('/');
-				if(type[0] == "text" && type[1] == "plain")
+				QByteArray type = params[0].first;
+
+				if(type == "text/plain" || type == "text/*" || type == "*/*" || type == "*")
 				{
 					responseContentType = "text/plain";
-					break;
 				}
-				else if(type[0] == "application" && type[1] == "json")
+				else if(type == "application/json" || type == "application/*")
 				{
 					responseContentType = "application/json";
-					break;
-				}
-				else if(type[0] == "text" && type[1] == "*")
-				{
-					responseContentType = "text/plain";
-					break;
-				}
-				else if(type[0] == "application" && type[1] == "*")
-				{
-					responseContentType = "application/json";
-					break;
-				}
-				else if(type[0] == "*" && type[1] == "*")
-				{
-					responseContentType = "text/plain";
-					break;
 				}
 			}
 
