@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2014-2019 Fanout, Inc.
+ * Copyright (C) 2014-2020 Fanout, Inc.
  *
  * This file is part of Pushpin.
  *
@@ -52,7 +52,6 @@
 #include "testwebsocket.h"
 
 #define ACTIVITY_TIMEOUT 60000
-#define FRAME_SIZE_MAX 16384
 #define KEEPALIVE_RAND_MAX 1000
 
 class HttpExtension
@@ -524,7 +523,12 @@ public:
 			if(target.overHttp)
 			{
 				WebSocketOverHttp *woh = new WebSocketOverHttp(zhttpManager, this);
+
 				woh->setConnectionId(publicCid);
+
+				if(target.oneEvent)
+					woh->setMaxEventsPerRequest(1);
+
 				connect(woh, &WebSocketOverHttp::aboutToSendRequest, this, &Private::out_aboutToSendRequest);
 				outSock = woh;
 			}
@@ -1009,35 +1013,15 @@ private slots:
 			return;
 		}
 
-		// split into frames to avoid credits issue
-		QList<WebSocket::Frame> frames;
+		WebSocket::Frame f(type, message, false);
 
-		for(int n = 0; frames.isEmpty() || n < message.size(); n += FRAME_SIZE_MAX)
+		if(outReadInProgress != -1)
 		{
-			WebSocket::Frame::Type ftype;
-			if(n == 0)
-				ftype = type;
-			else
-				ftype = WebSocket::Frame::Continuation;
-
-			QByteArray data = message.mid(n, FRAME_SIZE_MAX);
-			bool more = (n + FRAME_SIZE_MAX < message.size());
-
-			frames += WebSocket::Frame(ftype, data, more);
+			queuedInFrames += QueuedFrame(f, true);
 		}
-
-		for(int n = 0; n < frames.count(); ++n)
+		else
 		{
-			bool fromSendEvent = (n + 1 >= frames.count());
-
-			if(outReadInProgress != -1)
-			{
-				queuedInFrames += QueuedFrame(frames[n], fromSendEvent);
-			}
-			else
-			{
-				writeInFrame(frames[n], fromSendEvent);
-			}
+			writeInFrame(f, true);
 		}
 
 		adjustKeepAlive();
@@ -1066,13 +1050,13 @@ private slots:
 		}
 	}
 
-	void wsControl_closeEventReceived(int code)
+	void wsControl_closeEventReceived(int code, const QByteArray &reason)
 	{
 		if(!detached && outSock && outSock->state() != WebSocket::Closing)
 			outSock->close();
 
 		if(inSock && inSock->state() != WebSocket::Closing)
-			inSock->close(code);
+			inSock->close(code, reason);
 	}
 
 	void wsControl_detachEventReceived()
